@@ -20,8 +20,6 @@ import (
 	"context"
 	"fmt"
 	"os"
-	"path/filepath"
-	"sort"
 	"strings"
 	"time"
 
@@ -31,7 +29,6 @@ import (
 	"github.com/go-logr/logr"
 	"github.com/spf13/cobra"
 	"k8s.io/apimachinery/pkg/apis/meta/v1/unstructured"
-	"sigs.k8s.io/yaml"
 
 	apiv1 "github.com/stefanprodan/timoni/api/v1alpha1"
 	"github.com/stefanprodan/timoni/internal/engine"
@@ -89,6 +86,16 @@ The apply command performs the following steps:
   --values ./values-2.json
 `,
 	RunE: runApplyCmd,
+	ValidArgsFunction: func(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective) {
+		switch len(args) {
+		case 0:
+			return completeInstanceList(cmd, args, toComplete)
+		case 1:
+			return nil, cobra.ShellCompDirectiveFilterDirs
+		default:
+			return nil, cobra.ShellCompDirectiveNoFileComp
+		}
+	},
 }
 
 type applyFlags struct {
@@ -134,7 +141,7 @@ func runApplyCmd(cmd *cobra.Command, args []string) error {
 	applyArgs.name = args[0]
 	applyArgs.module = args[1]
 
-	log := LoggerFrom(cmd.Context(), "instance", applyArgs.name)
+	log := LoggerInstance(cmd.Context(), applyArgs.name)
 
 	version := applyArgs.version.String()
 	if version == "" {
@@ -248,19 +255,24 @@ func runApplyCmd(cmd *cobra.Command, args []string) error {
 		}
 	}
 
-	if applyArgs.dryrun || applyArgs.diff {
-		if !nsExists {
-			log.Info(fmt.Sprintf("Namespace/%s created (server dry run)", *kubeconfigArgs.Namespace))
-		}
-		return instanceDryRun(logr.NewContext(ctx, log), rm, objects, nsExists, tmpDir, applyArgs.diff)
-	}
-
 	im := runtime.NewInstanceManager(applyArgs.name, *kubeconfigArgs.Namespace, finalValues, *mod)
 
 	if err := im.AddObjects(objects); err != nil {
 		return fmt.Errorf("adding objects to instance failed: %w", err)
 	}
 
+	staleObjects, err := sm.GetStaleObjects(ctx, &im.Instance)
+	if err != nil {
+		return fmt.Errorf("getting stale objects failed: %w", err)
+	}
+
+	if applyArgs.dryrun || applyArgs.diff {
+		if !nsExists {
+			log.Info(colorizeJoin(colorizeNamespaceFromArgs(), ssa.CreatedAction, dryRunServer))
+		}
+		return instanceDryRunDiff(logr.NewContext(ctx, log), rm, objects, staleObjects, nsExists, tmpDir, applyArgs.diff)
+	}
+
 	if !exists {
 		log.Info(fmt.Sprintf("installing %s in namespace %s", applyArgs.name, *kubeconfigArgs.Namespace))
 
@@ -269,7 +281,7 @@ func runApplyCmd(cmd *cobra.Command, args []string) error {
 		}
 
 		if !nsExists {
-			log.Info(fmt.Sprintf("Namespace/%s created", *kubeconfigArgs.Namespace))
+			log.Info(colorizeJoin(colorizeNamespaceFromArgs(), ssa.CreatedAction))
 		}
 	} else {
 		log.Info(fmt.Sprintf("upgrading %s in namespace %s", applyArgs.name, *kubeconfigArgs.Namespace))
@@ -291,7 +303,7 @@ func runApplyCmd(cmd *cobra.Command, args []string) error {
 			return err
 		}
 		for _, change := range cs.Entries {
-			log.Info(change.String())
+			log.Info(colorizeJoin(change))
 		}
 
 		if applyArgs.wait {
@@ -305,11 +317,6 @@ func runApplyCmd(cmd *cobra.Command, args []string) error {
 		}
 	}
 
-	staleObjects, err := sm.GetStaleObjects(ctx, &im.Instance)
-	if err != nil {
-		return fmt.Errorf("getting stale objects failed: %w", err)
-	}
-
 	if err := sm.Apply(ctx, &im.Instance, true); err != nil {
 		return fmt.Errorf("storing instance failed: %w", err)
 	}
@@ -319,11 +326,11 @@ func runApplyCmd(cmd *cobra.Command, args []string) error {
 		deleteOpts := runtime.DeleteOptions(applyArgs.name, *kubeconfigArgs.Namespace)
 		changeSet, err := rm.DeleteAll(ctx, staleObjects, deleteOpts)
 		if err != nil {
-			return fmt.Errorf("prunning objects failed: %w", err)
+			return fmt.Errorf("pruning objects failed: %w", err)
 		}
 		deletedObjects = runtime.SelectObjectsFromSet(changeSet, ssa.DeletedAction)
 		for _, change := range changeSet.Entries {
-			log.Info(change.String())
+			log.Info(colorizeJoin(change))
 		}
 	}
 
@@ -333,7 +340,7 @@ func runApplyCmd(cmd *cobra.Command, args []string) error {
 			err = rm.WaitForTermination(deletedObjects, waitOptions)
 			spin.Stop()
 			if err != nil {
-				return fmt.Errorf("wating for termination failed: %w", err)
+				return fmt.Errorf("waiting for termination failed: %w", err)
 			}
 
 			log.Info("all resources are ready")
@@ -349,47 +356,3 @@ func instanceOwnershipConflicts(instance apiv1.Instance) error {
 	}
 	return nil
 }
-
-func instanceDryRun(ctx context.Context,
-	rm *ssa.ResourceManager,
-	objects []*unstructured.Unstructured,
-	nsExists bool,
-	tmpDir string,
-	withDiff bool) error {
-	log := LoggerFrom(ctx)
-	diffOpts := ssa.DefaultDiffOptions()
-	sort.Sort(ssa.SortableUnstructureds(objects))
-
-	for _, r := range objects {
-		if !nsExists {
-			log.Info(fmt.Sprintf("%s created (server dry run)", ssa.FmtUnstructured(r)))
-			continue
-		}
-
-		change, liveObject, mergedObject, err := rm.Diff(ctx, r, diffOpts)
-		if err != nil {
-			log.Error(err, "diff failed")
-			continue
-		}
-
-		log.Info(fmt.Sprintf("%s (server dry run)", change.String()))
-		if withDiff && change.Action == ssa.ConfiguredAction {
-			liveYAML, _ := yaml.Marshal(liveObject)
-			liveFile := filepath.Join(tmpDir, "live.yaml")
-			if err := os.WriteFile(liveFile, liveYAML, 0644); err != nil {
-				return err
-			}
-
-			mergedYAML, _ := yaml.Marshal(mergedObject)
-			mergedFile := filepath.Join(tmpDir, "merged.yaml")
-			if err := os.WriteFile(mergedFile, mergedYAML, 0644); err != nil {
-				return err
-			}
-
-			if err := diffYAML(liveFile, mergedFile, rootCmd.OutOrStdout()); err != nil {
-				return err
-			}
-		}
-	}
-	return nil
-}
