@@ -129,7 +129,7 @@ func runBundleApplyCmd(cmd *cobra.Command, _ []string) error {
 		return err
 	}
 
-	log := LoggerFrom(cmd.Context(), "bundle", bundle.Name)
+	log := LoggerBundle(cmd.Context(), bundle.Name)
 
 	if !bundleApplyArgs.overwriteOwnership {
 		err = bundleInstancesOwnershipConflicts(bundle.Instances)
@@ -168,7 +168,7 @@ func applyBundleInstance(ctx context.Context, cuectx *cue.Context, instance engi
 		moduleVersion = "@" + instance.Module.Digest
 	}
 
-	log := LoggerFrom(ctx, "instance", instance.Name)
+	log := LoggerBundleInstance(ctx, instance.Bundle, instance.Name)
 	log.Info(fmt.Sprintf("pulling %s", sourceURL))
 
 	tmpDir, err := os.MkdirTemp("", apiv1.FieldManager)
@@ -259,18 +259,6 @@ func applyBundleInstance(ctx context.Context, cuectx *cue.Context, instance engi
 		return fmt.Errorf("instance init failed: %w", err)
 	}
 
-	if bundleApplyArgs.dryrun || bundleApplyArgs.diff {
-		if !nsExists {
-			log.Info(fmt.Sprintf("Namespace/%s created (server dry run)", instance.Namespace))
-		}
-		if err := instanceDryRun(logr.NewContext(ctx, log), rm, objects, nsExists, tmpDir, bundleApplyArgs.diff); err != nil {
-			return err
-		}
-
-		log.Info("applied successfully (server dry run)")
-		return nil
-	}
-
 	im := runtime.NewInstanceManager(instance.Name, instance.Namespace, finalValues, *mod)
 
 	if im.Instance.Labels == nil {
@@ -282,6 +270,23 @@ func applyBundleInstance(ctx context.Context, cuectx *cue.Context, instance engi
 		return fmt.Errorf("adding objects to instance failed: %w", err)
 	}
 
+	staleObjects, err := sm.GetStaleObjects(ctx, &im.Instance)
+	if err != nil {
+		return fmt.Errorf("getting stale objects failed: %w", err)
+	}
+
+	if bundleApplyArgs.dryrun || bundleApplyArgs.diff {
+		if !nsExists {
+			log.Info(colorizeJoin(colorizeNamespaceFromArgs(), ssa.CreatedAction, dryRunServer))
+		}
+		if err := instanceDryRunDiff(logr.NewContext(ctx, log), rm, objects, staleObjects, nsExists, tmpDir, bundleApplyArgs.diff); err != nil {
+			return err
+		}
+
+		log.Info("applied successfully (server dry run)")
+		return nil
+	}
+
 	if !exists {
 		log.Info(fmt.Sprintf("installing %s in namespace %s", instance.Name, instance.Namespace))
 
@@ -290,7 +295,7 @@ func applyBundleInstance(ctx context.Context, cuectx *cue.Context, instance engi
 		}
 
 		if !nsExists {
-			log.Info(fmt.Sprintf("Namespace/%s created", instance.Namespace))
+			log.Info(colorizeJoin(colorizeNamespaceFromArgs(), ssa.CreatedAction))
 		}
 	} else {
 		log.Info(fmt.Sprintf("upgrading %s in namespace %s", instance.Name, instance.Namespace))
@@ -312,7 +317,7 @@ func applyBundleInstance(ctx context.Context, cuectx *cue.Context, instance engi
 			return err
 		}
 		for _, change := range cs.Entries {
-			log.Info(change.String())
+			log.Info(colorizeJoin(change))
 		}
 
 		if bundleApplyArgs.wait {
@@ -326,11 +331,6 @@ func applyBundleInstance(ctx context.Context, cuectx *cue.Context, instance engi
 		}
 	}
 
-	staleObjects, err := sm.GetStaleObjects(ctx, &im.Instance)
-	if err != nil {
-		return fmt.Errorf("getting stale objects failed: %w", err)
-	}
-
 	if err := sm.Apply(ctx, &im.Instance, true); err != nil {
 		return fmt.Errorf("storing instance failed: %w", err)
 	}
@@ -340,11 +340,11 @@ func applyBundleInstance(ctx context.Context, cuectx *cue.Context, instance engi
 		deleteOpts := runtime.DeleteOptions(instance.Name, instance.Namespace)
 		changeSet, err := rm.DeleteAll(ctx, staleObjects, deleteOpts)
 		if err != nil {
-			return fmt.Errorf("prunning objects failed: %w", err)
+			return fmt.Errorf("pruning objects failed: %w", err)
 		}
 		deletedObjects = runtime.SelectObjectsFromSet(changeSet, ssa.DeletedAction)
 		for _, change := range changeSet.Entries {
-			log.Info(change.String())
+			log.Info(colorizeJoin(change))
 		}
 	}
 
